.. _utilities:

.. module:: utils

==========================
Utilities
==========================



.. module:: dynts.utils.wrappers

Timeseries wrappers
============================


As Binary Tree
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: dynts.utils.wrappers.asbtree
   :members:
   :member-order: bysource
   
   

As Hash Table
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: dynts.utils.wrappers.ashash
   :members:
   :member-order: bysource
   
   

Iterators
================================

.. automodule:: dynts.utils.iterators
   :members:  